<?php 
/**
 * Study Abroad Template
 * Destination section
 *
 * This is the template for the content of destination section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_study_abroad_destination_section' ) ) :
    /**
    * Add destination section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_study_abroad_destination_section() {
        $options = elead_pro_get_theme_options();

        // Check if destination is enabled
        $enable_study_abroad_destination = $options['destination_enable'];

        if ( true !== $enable_study_abroad_destination ) {
            return false;
        }

        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_study_abroad_destination_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render destination section now.
        elead_pro_render_study_abroad_destination_section( $section_details );
    }
endif;
add_action( 'elead_pro_study_abroad_content', 'elead_pro_add_study_abroad_destination_section', 10 );


if ( ! function_exists( 'elead_pro_get_study_abroad_destination_section_details' ) ) :
    /**
    * destination section details.
    *
    * @since Elead Pro 1.0
    * @param array $input destination section details.
    */
    function elead_pro_get_study_abroad_destination_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // destination type
        $study_abroad_destination_content_type  = $options['destination_content_type'];
        $no_of_destinations  = ! empty( $options['study_abroad_destination_count'] ) ? $options['study_abroad_destination_count'] : 3;

        $content = array();
        switch ( $study_abroad_destination_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['study_abroad_destination_post'] ) )
                    $ids = ( array ) $options['study_abroad_destination_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  
                
          	break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['study_abroad_destination_category'] ) ) {
                    $cat_id = $options['study_abroad_destination_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_destinations ),
                );
            break;

            case 'excursion':
                $ids = array();
                
                if ( ! empty( $options['study_abroad_destination_excursion'] ) )
                    $ids = ( array ) $options['study_abroad_destination_excursion'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-excursion',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  

            break;

            case 'excursion-category':
                $cat_id = '';
                if ( ! empty( $options['study_abroad_destination_excursion_category'] ) ) {
                    $cat_id = $options['study_abroad_destination_excursion_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-excursion',
                    'posts_per_page'    => absint( $no_of_destinations ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-excursion-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                
            break;

            case 'custom':
                for ( $i = 1; $i <= absint( $no_of_destinations ); $i++ ) :

                    $content[$i]['title']       = ! empty( $options['destination_custom_title_'.$i ] ) ? $options['destination_custom_title_'.$i ] : esc_html__( 'Study In USA','elead-pro' );  
                    $content[$i]['excerpt']     = ! empty( $options['destination_custom_excerpt_'.$i ] ) ? $options['destination_custom_excerpt_'.$i ] : esc_html__( 'Interdum et malesuada fames ac ante ipsum primis in faucibus. Fusce male sua da ante sed rhoncus blandit','elead-pro' );        
                    $content[$i]['img_array'][0]   = ! empty( $options['destination_custom_image_'.$i ] ) ? $options['destination_custom_image_'.$i ] : get_template_directory_uri() . '/assets/uploads/abroad-country-01.jpg';
                    $content[$i]['img_array'][1] = 360;       
                    $content[$i]['img_array'][2] = 300;        
                    $content[$i]['url']         = ! empty( $options['destination_custom_url_'.$i ] ) ? $options['destination_custom_url_'.$i ] : esc_html__( '#','elead-pro' );
                endfor;
            break;

        }
        if ( 'custom' != $study_abroad_destination_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'post-thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                        $img_array[1] =  360;
                        $img_array[2] =  300;
                    }
                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = elead_pro_trim_content( 15, $post );
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'elead_pro_filter_study_abroad_destination_section_details', 'elead_pro_get_study_abroad_destination_section_details' );


if ( ! function_exists( 'elead_pro_render_study_abroad_destination_section' ) ) :
    /**
    * Start destination section
    *
    * @return string destination content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_study_abroad_destination_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        
        $read_more = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'elead-pro' );
        $content_type  = $options['destination_content_type'];

        $category_link  = '';
        $cat_name       = '';
        if ( $content_type == 'category' ) {
            $category_link  = get_category_link( $options['study_abroad_destination_category'] );
            $cat_name       = get_the_category_by_ID( $options['study_abroad_destination_category'] );
        } elseif ( $content_type == 'excursion-category' ) {
            $category_link  = get_term_link( $options['study_abroad_destination_excursion_category' ], 'tp-excursion-category' );
            $term           = get_term_by('id', $options['study_abroad_destination_excursion_category' ] , 'tp-excursion-category' );
            $cat_name       = $term->name;
        } else {
            $category_link = ! empty( $options['destination_custom_btn_url'] ) ? $options['destination_custom_btn_url'] : '#';
            $cat_name      = ! empty( $options['destination_custom_btn_label'] ) ? $options['destination_custom_btn_label'] : '#';
        }

        if ( empty( $content_details ) ) {
            return;
        }

        ?>
        <div class="abroad-countries-list col-3 clear">
            <?php foreach ( $content_details as $content_detail ) : ?>
                <div class="hentry">
                    <div class="abroad-countries-wrapper">
                        <?php if ( ! empty( $content_detail['img_array'][0] ) ) : ?> 
                            <figure class="featured-image">
                                <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>"></a>
                            </figure>
                        <?php endif; ?>

                        <div class="entry-container">
                            <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                            <h5 class="featured-title"><a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                            <?php endif; 
                            if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                                <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                            <?php endif; ?>
                            <div class="align-center">
                                <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>" class="btn btn-transparent"><?php echo esc_html( $read_more ); ?></a>
                            </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </div><!-- .featured-course-wrapper -->
                </div><!-- .hentry -->
            <?php endforeach; ?>
        </div><!-- .abroad-countries-list -->

        <?php if ( ! empty( $category_link ) && ! in_array( $content_type, array( 'custom', 'post', 'excursion' ) ) ) : ?>
            <div class="align-center">
                <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'elead-pro' ) ); ?></a>
            </div>
        <?php 
        else : ?>
            <div class="align-center">
                <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-transparent"><?php echo esc_html( $cat_name ); ?></a>
            </div>
        <?php 
        endif;
    }
endif;


/**
 * Study Abroad Template
 * Study guide section
 *
 * This is the template for the content of study guide section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_study_abroad_guide_section' ) ) :
    /**
    * Add study guide section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_study_abroad_guide_section() {
        $options = elead_pro_get_theme_options();

        // Check if study guide is enabled
        $enable_study_abroad_guide = $options['study_guide_enable'];

        if ( true !== $enable_study_abroad_guide ) {
            return false;
        }

        // Get study guide section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_study_guide_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render study guide section now.
        elead_pro_render_study_abroad_guide_section( $section_details );
    }
endif;
add_action( 'elead_pro_study_guide_content', 'elead_pro_add_study_abroad_guide_section', 10 );


if ( ! function_exists( 'elead_pro_get_study_abroad_guide_section_details' ) ) :
    /**
    * study guide section details.
    *
    * @since Elead Pro 1.0
    * @param array $input study guide section details.
    */
    function elead_pro_get_study_abroad_guide_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // study guide type
        $study_guide_content_type  = $options['study_guide_content_type'];
        $no_of_study_guides  = ! empty( $options['study_abroad_guide_count'] ) ? $options['study_abroad_guide_count'] : 6;

        $content = array();
        $args = array();
        switch ( $study_guide_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['study_guide_content_post'] ) )
                    $ids = ( array ) $options['study_guide_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  
                
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['study_guide_content_category'] ) ) {
                    $cat_id = $options['study_guide_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_study_guides ),
                );
            break;

            case 'custom':
                for ( $i = 1; $i <= absint( $no_of_study_guides ); $i++ ) :

                    $content[$i]['title'] = ! empty( $options['study_guide_custom_title_'.$i ] ) ? $options['study_guide_custom_title_'.$i] : esc_html__( 'Scholarships','elead-pro' );       
                    $content[$i]['excerpt'] = ! empty( $options['study_guide_custom_excerpt_'.$i ] ) ? $options['study_guide_custom_excerpt_'.$i] : esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi','elead-pro' );
                    $content[$i]['url'] = ! empty( $options['study_guide_custom_url_'.$i ] ) ? $options['study_guide_custom_url_'.$i] : esc_html__( '#','elead-pro' );
                    $content[$i]['icon'] = ! empty( $options['study_guide_custom_icon_'.$i ] ) ? $options['study_guide_custom_icon_'.$i] : 'fa-graduation-cap';
                endfor;
            
            break;

        }
        if ( 'custom' != $study_guide_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $content[$i]['icon']    = get_post_meta( $post_id, 'elead-pro-post-icon', true );
                    $content[$i]['title']   = get_the_title( $post_id );
                    $content[$i]['url']     = get_the_permalink( $post_id );
                    $content[$i]['excerpt'] = elead_pro_trim_content( 15, $post );
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// study guide section content details.
add_filter( 'elead_pro_filter_study_guide_details', 'elead_pro_get_study_abroad_guide_section_details' );


if ( ! function_exists( 'elead_pro_render_study_abroad_guide_section' ) ) :
    /**
    * Start study guide section
    *
    * @return string study guide content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_study_abroad_guide_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        
        $study_guide_title = ! empty( $options['study_guide_title'] ) ? $options['study_guide_title'] : '';
        $study_guide_sub_title = ! empty( $options['study_guide_sub_title'] ) ? $options['study_guide_sub_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="abroad-study-guidelines" class="page-section parallax" style="background-image: url('<?php echo get_template_directory_uri() . '/assets/uploads/promotion.jpg'; ?>'); background-position: 0% 60px;" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
            <div class="wrapper">
                <?php if ( ! empty( $study_guide_title ) || ! empty( $study_guide_sub_title ) ) : ?>
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $study_guide_title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $study_guide_title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $study_guide_sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $study_guide_sub_title ); ?></p>
                        <?php endif; ?>
                    </header>
                <?php endif; ?>

                <div class="entry-content col-3">
                    <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <?php if ( ! empty( $content_detail['icon'] ) ) : ?>
                                <div class="icon">
                                    <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>">
                                        <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                                    </a>
                                </div><!-- .icon -->
                            <?php endif; ?>
                            <div class="details">
                                <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                                <h5 class="featured-title">
                                    <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>">
                                        <?php echo esc_html( $content_detail['title'] ); ?>
                                    </a>
                                </h5>
                                <?php endif;
                                if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                <?php endif; ?>
                            </div><!-- .details -->
                        </div><!-- .hentry -->
                    <?php endforeach; ?>
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </section><!-- #abroad-study-guidelines -->
    <?php }
endif;