<?php
/**
 * Study Abroad Template options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

// Add panel for Study Abroad Template
$wp_customize->add_panel( 'elead_pro_study_abroad_panel' , array(
    'title'      => esc_html__( 'Study Abroad Template','elead-pro' ),
    'description'=> esc_html__( 'Study Abroad Template Options', 'elead-pro' ),
    'priority'   => 150,
) );

/*
 * Destination Section
 */

$wp_customize->add_section( 'elead_pro_destination', array(
	'title'             => esc_html__( 'Destination Section','elead-pro' ),
	'description'       => esc_html__( 'Destination section options.', 'elead-pro' ),
	'panel'             => 'elead_pro_study_abroad_panel',
) );

// Destination Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[destination_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['destination_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[destination_enable]', array(
	'label'            	=> esc_html__( 'Enable Destination', 'elead-pro' ),
	'section'          	=> 'elead_pro_destination',
	'type'             	=> 'checkbox',
) );

// Destination Section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[destination_content_type]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
	'default'          	=> $options['destination_content_type'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[destination_content_type]', array(
	'label'            	=> esc_html__( 'Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_destination',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_abroad_study_destination_enable',
	'choices'			=> elead_pro_study_abroad_destination(),
) );

// Add destination section count setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_abroad_destination_count]', array(
	'default'           => $options['study_abroad_destination_count'],
	'sanitize_callback' => 'elead_pro_sanitize_number_range',
	'validate_callback' => 'elead_pro_validate_destination_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_abroad_destination_count]', array(
	'label'           	=> esc_html__( 'Number of Destinations', 'elead-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'elead-pro' ),
	'section'         	=> 'elead_pro_destination',
	'type'            	=> 'number',
	'active_callback' 	=> 'elead_pro_study_abroad_destination_count',
	'input_attrs'     	=> array(
		'max' 	=> 6,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// destination section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_abroad_destination_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_abroad_destination_post]', array(
	'active_callback'	=> 'elead_pro_study_abroad_destination_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Max no. of posts allowed is 6. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_destination',
	'type'				=> 'text',
) );

// destination section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[study_abroad_destination_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[study_abroad_destination_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_destination',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_study_abroad_destination_category',
) ) );

// destination section content type excursion setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_abroad_destination_excursion]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_abroad_destination_excursion]', array(
	'active_callback'	=> 'elead_pro_study_abroad_destination_excursion',
	'label'             => esc_html__( 'Input Excursion Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Max no. of posts allowed is 6. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_destination',
	'type'				=> 'text',
) );

// destination section content type excursion category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[study_abroad_destination_excursion_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[study_abroad_destination_excursion_category]', array(
	'label'           => esc_html__( 'Select Excursion Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest excursions from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_destination',
	'taxonomy'		  => 'tp-excursion-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_study_abroad_destination_excursion_category',
) ) );

for ( $i = 1; $i <= $options['study_abroad_destination_count']; $i++ ) {
	
	// destination section custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[destination_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_destination',
			'active_callback' => 'elead_pro_study_abroad_destination_custom',
			'type'			  => 'hr'
	) ) );

	// destination section custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[destination_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Destination %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_destination',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_study_abroad_destination_custom',
	) ) );

	// destination section custom background image setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_image_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_image',
		'default'			=> get_template_directory_uri() . '/assets/uploads/abroad-country-01.jpg',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[destination_custom_image_'.$i.']',
			array(
			'label'       		=> sprintf( esc_html__( 'Custom Image %s', 'elead-pro' ),$i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 360, 300 ),
			'section'     		=> 'elead_pro_destination',
			'active_callback'	=> 'elead_pro_study_abroad_destination_custom',
	) ) );

	// destination section custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Study In USA','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[destination_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_study_abroad_destination_custom',
		'label'             => sprintf( esc_html__( 'Custom Title %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_destination',
		'type'				=> 'text'
	) );

	// destination section custom title link setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_url_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( '#','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[destination_custom_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_study_abroad_destination_custom',
		'label'             => sprintf( esc_html__( 'Custom Title url %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_destination',
		'type'				=> 'text'
	) );

	// destination section custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'			=> esc_html__( 'Interdum et malesuada fames ac ante ipsum primis in faucibus. Fusce male sua da ante sed rhoncus blandit','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[destination_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_study_abroad_destination_custom',
		'label'             => sprintf( esc_html__( 'Custom Excerpt %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_destination',
		'type'				=> 'textarea'
	) );
}

// destination Section button label setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_btn_label]', array(
	'default'           => $options['destination_custom_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[destination_custom_btn_label]', array(
	'active_callback'	=> 'elead_pro_destination_content_category_disable',
	'label'             => esc_html__( 'Custom button label', 'elead-pro' ),
	'section'           => 'elead_pro_destination',
	'type'				=> 'text'
) );

// destination Section button label url setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[destination_custom_btn_url]', array(
	'default'           => $options['destination_custom_btn_url'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[destination_custom_btn_url]', array(
	'active_callback'	=> 'elead_pro_destination_content_category_disable',
	'label'             => esc_html__( 'Custom button url', 'elead-pro' ),
	'section'           => 'elead_pro_destination',
	'type'				=> 'text'
) );
/*
 * Study Guide Section
 */

$wp_customize->add_section( 'elead_pro_guide', array(
	'title'             => esc_html__( 'Study Guide Section','elead-pro' ),
	'description'       => esc_html__( 'Study Guide section options.', 'elead-pro' ),
	'panel'             => 'elead_pro_study_abroad_panel',
) );

// Study Guide enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['study_guide_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_guide_enable]', array(
	'label'            	=> esc_html__( 'Enable Study Guide', 'elead-pro' ),
	'section'          	=> 'elead_pro_guide',
	'type'             	=> 'checkbox',
) );

// Study Guide title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['study_guide_title'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_guide_title]', array(
	'label'            	=> esc_html__( 'Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_guide',
	'type'             	=> 'text',
) );

// Study Guide sub title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['study_guide_sub_title'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_guide_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_guide',
	'type'             	=> 'text',
) );

// Study Guide Section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_content_type]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
	'default'          	=> $options['study_guide_content_type'],

) );

$wp_customize->add_control( 'elead_pro_theme_options[study_guide_content_type]', array(
	'label'            	=> esc_html__( 'Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_guide',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_abroad_study_destination_enable',
	'choices'			=> elead_pro_study_guide(),
) );

// Study guide Section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_content_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_guide_content_post]', array(
	'active_callback'	=> 'elead_pro_study_guide_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Max no. of posts allowed is 9. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_guide',
	'type'				=> 'text',
) );

// Study guide count setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_count]', array(
	'default'           => $options['study_guide_count'],
	'sanitize_callback' => 'elead_pro_sanitize_number_range',
	'validate_callback' => 'elead_pro_validate_study_guide_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[study_guide_count]', array(
	'label'           	=> esc_html__( 'Number of Guides', 'elead-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change', 'elead-pro' ),
	'section'         	=> 'elead_pro_guide',
	'type'            	=> 'number',
	'active_callback' 	=> 'elead_pro_study_guide_content_not_post',
	'input_attrs'     	=> array(
		'max' 	=> 9,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// study guide content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[study_guide_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_guide',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_study_guide_content_category',
) ) );


for ( $i = 1; $i <= $options['study_guide_count']; $i++ ) {

	// study guide custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[study_guide_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_guide',
			'active_callback' => 'elead_pro_study_guide_content_custom',
			'type'			  => 'hr'
	) ) );

	// study guide custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[study_guide_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Study Guide %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_guide',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_study_guide_content_custom',
	) ) );

	// study guide custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Scholarships','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[study_guide_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_study_guide_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_guide',
		'type'				=> 'text'
	) );

	// study guide custom title link setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_custom_url_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
		'default'			=> esc_html__( '#','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[study_guide_custom_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_study_guide_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title Url %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_guide',
		'type'				=> 'url'
	) );

	// study guide custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'			=> esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi.','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[study_guide_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_study_guide_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Excerpt %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_guide',
		'type'				=> 'textarea'
	) );

	// study guide custom icon setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[study_guide_custom_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> 'fa-graduation-cap',
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[study_guide_custom_icon_'.$i.']', array(
		'active_callback'	=> 'elead_pro_study_guide_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Icon %s', 'elead-pro' ),$i ),
		'description'     	=> sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$s See more here %3$s', 'elead-pro' ), 'fa-users', '<a href="' . esc_url( 'http://fontawesome.io/icons/' ) . '" target="_blank">', '</a>' ),
		'section'           => 'elead_pro_guide',
		'type'				=> 'text'
	) );
}