<?php 
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_counter_section() {
        $options = elead_pro_get_theme_options();

        // Check if counter is enabled
        $enable_counter = apply_filters( 'elead_pro_section_status', true, 'counter_enable' );

        if ( true !== $enable_counter ) {
            return false;
        }

        // Render counter section now.
        elead_pro_render_counter_section();
    }
endif;
add_action( 'elead_pro_primary_content_action', 'elead_pro_add_counter_section', 80 );

if ( ! function_exists( 'elead_pro_render_counter_section' ) ) :
    /**
    * Start counter section
    *
    * @return string counter content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_counter_section() {
        $options = elead_pro_get_theme_options();
        $background = ! empty( $options['counter_image'] ) ? $options['counter_image'] : '';
        ?>
        <section id="counter" class="page-section col-4" style="background-image:url('<?php echo esc_url( $background ); ?>')" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
            <div class="wrapper">
                <?php for ( $i = 1; $i <= 4; $i++ ) :
                    $icon   = ! empty( $options['counter_icon_' . $i] ) ? $options['counter_icon_' . $i] : '';
                    $value  = ! empty( $options['counter_count_' . $i] ) ? $options['counter_count_' . $i] : '';
                    $title  = ! empty( $options['counter_title_' . $i] ) ? $options['counter_title_' . $i] : '';
                    if ( ! empty( $value ) && ! empty( $title ) ) :
                    ?>
                        <div class="hentry">
                            <div class="statwrap">
                                <i class="fa <?php echo esc_attr( $icon ); ?>"></i>
                                <h1 class="stat-count"><?php echo absint( $value ); ?></h1>
                                <small><?php echo esc_html( $title ); ?></small>
                            </div><!-- .statwrap -->
                        </div><!-- .hentry -->
                    <?php endif;
                endfor; ?>
            </div><!-- .wrapper -->
        </section><!-- #counter -->
    <?php }
endif;
